#
# spec file for package nauty
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           nauty
%define lname   libnauty-2_6_10
%define fuv      26r10
Version:        2.6.10
Release:        lp152.3.7
Summary:        Tools for computing automorphism groups of graphs
License:        Apache-2.0
Group:          Productivity/Scientific/Math
URL:            http://pallini.di.uniroma1.it/

Source:         http://pallini.di.uniroma1.it/nauty%fuv.tar.gz
Patch1:         nauty-am.diff
Patch2:         nauty-uninitialized.diff
BuildRequires:  automake
BuildRequires:  gmp-devel
BuildRequires:  libtool >= 2
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
nauty and Traces are programs for computing automorphism groups of
graphs and digraphs (*Traces does not accept digraphs at this time).
They can also produce a canonical label. They are written in a
portable subset of C, and run on a considerable number of different
systems.

There is a small suite of programs called gtools included in the
package. For example, geng can generate non-isomorphic graphs very
quickly. There are also generators for bipartite graphs, digraphs,
and multigraphs.

%package -n %lname
Summary:        Graph automorphism group computation with Nauty
Group:          System/Libraries

%description -n %lname
nauty and Traces are programs for computing automorphism groups of
graphs and digraphs. They can also produce a canonical label.

%package devel
Summary:        Development files for nauty, a math library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
nauty and Traces are programs for computing automorphism groups of
graphs and digraphs. They can also produce a canonical label.

This subpackage contains the header files for developing
applications that want to make use of libnauty.

%prep
%setup -qn nauty%fuv
%patch -P 1 -P 2 -p1

%build
rm -f makefile
autoreconf -fi
export CFLAGS="%optflags -Wno-unused"
%configure
make %{?_smp_mflags}

%install
%make_install
rm -f "%buildroot/%_libdir"/*.la

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files
%defattr(-,root,root)
%_bindir/*
%doc COPYRIGHT

%files -n %lname
%defattr(-,root,root)
%_libdir/libnauty*-2.6.7.so

%files devel
%defattr(-,root,root)
%_includedir/nauty/
%_libdir/libnauty.so
%_libdir/libnautyA1.so
%_libdir/libnautyL0.so
%_libdir/libnautyL1.so
%_libdir/libnautyS0.so
%_libdir/libnautyS1.so
%_libdir/libnautyW0.so
%_libdir/libnautyW1.so

%changelog
* Mon Apr 30 2018 jengelh@inai.de
- Update to new upstream release 2.6.10
  * Problems with input of graphs with 0 vertices were fixed.
    Many utilities in the package will not work with such graphs.
    It is NOT TRUE that graphs of order 0 are now supported.
  * Stronger measures are taken to ensure that the sort order
    used by shortg is plain byte order. This corresponds to the C
    collation order, also known as POSIX, but it may be different
    from the collation order used by default on your command
    line. This means that utilities like sort, uniq, comm and
    join might consider the output of shortg to be out of order.
    To avoid this, define the environment variable LC_ALL to
    equal the string "C":
  * bash: export LC_ALL=C
  * tcsh: setenv LC_ALL C
  * If LC_ALL is undefined, it will also be sufficient to define
    LC_COLLATE to equal "C". The POSIX standard says that LC_ALL
    takes precedence over LC_COLLATE if both are defined, but
    this might not be true for older systems.
* Thu Sep 14 2017 jengelh@inai.de
- Update to new upstream release 2.6.7;
  initial version for build.opensuse.org
  * Switch from Non-Commercial Non-Military license to Apache-2.0
  * The "dreadnaut" tool now catches control-C when nauty or Traces
    is running. This uses the global variable nauty_kill_request.
  * dreadnaut: new command "vv" to display sorted degree sequence.
  * dreadnaut: new command "r&" to relabel according to the
    partition.
  * dreadnaut: new command "->>" to flush the output.
  * dreadnaut: new command "B" to turn on output flushing at the
    end of every command. Command "-B" turns it off. Default off.
  * dreadnaut: Command with short arguments now have to be all on
    one line. Most errors cause the rest of the input line to be
    skipped.
  * dreadnaut: The "R" command now preserves the colouring.
  * The "nauty" tool has an extra hook usercanonproc().
  * nauty: The maximum number of vertices is now 2 billion.
- Add nauty-am.diff, nauty-uninitialized.diff
* Sat May 18 2013 jengelh@inai.de
- Initial package (version 2.5.3)
